<?php
/* --------------------------------------------------------------
   ThemeService.inc.php 2018-11-14
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

/**
 * Class ThemeService
 */
class ThemeService implements ThemeServiceInterface
{
    /**
     * @var \ThemeRepositoryInterface
     */
    protected $repository;


    /**
     * ThemeService constructor.
     *
     * @param \ThemeRepositoryInterface $repository
     */
    public function __construct(ThemeRepositoryInterface $repository)
    {
        $this->repository = $repository;
    }


    /**
     * Get Available themes.
     *
     * @param \ThemeDirectoryRootInterface $source
     *
     * @return \ThemeNameCollection
     */
    public function getAvailableThemes(ThemeDirectoryRootInterface $source)
    {
        return $this->repository->getAvailableThemes($source);
    }


    /**
     * build a temporary theme.
     *
     * @param \ThemeId $themeId
     * @param \ThemeSettingsInterface $settings
     *
     * @return void
     */
    public function buildTemporaryTheme(ThemeId $themeId, ThemeSettingsInterface $settings)
    {
        $theme = $this->repository->getById($themeId, $settings->getSource());
        $this->repository->save($theme, $settings->getDestination());
    }
}