<?php
/* --------------------------------------------------------------
   HubPayPalButtonSettings.inc.php 2019-04-12
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2018 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

use HubPublic\Http\CurlRequest;

class HubPayPalButtonSettings
{
    protected $config;
    
    public function __construct(HubPayPalConfiguration $configuration)
    {
        $this->config = $configuration;
    }
    
    
    /**
     * Returns an array representing a PayPal Smart Buttons configuration.
     *
     * @return array
     */
    public function getButtonSettings()
    {
        $paypalLocaleFactory = MainFactory::create('HubPayPalLocaleFactory');

        $buttonConfig = [
            'jssrc'                => $this->getJavascriptSource(),
            'env'                  => $this->config->getEnv() === 'production' ? 'production' : 'sandbox',
            'commit'               => false,
            'style'                => [
                'label'        => $this->config->getStyleLabel(),
                'shape'        => $this->config->getStyleShape(),
                'color'        => $this->config->getStyleColor(),
                'layout'       => $this->config->getStyleLayout(),
                'tagline'      => $this->config->isStyleTagline(),
            ],
            'locale'               => $paypalLocaleFactory->getLocaleByLanguageAndCountry($_SESSION['language_code'],$_SESSION['delivery_zone']),
            'fundingCardAllowed'   => $this->config->isFundingCardAllowed(),
            'fundingELVAllowed'    => $this->config->isFundingELVAllowed(),
            'fundingCreditAllowed' => $this->config->isFundingCreditAllowed(),
            'createPaymentUrl'     => '',
            'authorizedPaymentUrl' => '',
            'checkoutUrl'          => '',
        ];
        
        return $buttonConfig;
    }
    
    public function getECMButtonSettings()
    {
        $ecmButtonConfig = $this->getButtonSettings();
        $ecmButtonConfig['jssrc'] = $this->getJavascriptSource('ecm');
        $ecmButtonConfig['style']['layout'] = 'horizontal';
        $ecmButtonConfig['style']['label'] = 'checkout';
        return $ecmButtonConfig;
    }
    
    
    protected function getJavascriptSource($position = 'cart')
    {
        $sessionKey = 'paypalhub-jssrc-' . $position;
        if (isset($_SESSION[$sessionKey])) {
            return $_SESSION[$sessionKey];
        }
        
        $query = [
            'client_key' => gm_get_conf('GAMBIO_HUB_CLIENT_KEY'),
            'devmode'    => file_exists(DIR_FS_CATALOG . '/.dev-environment') ? 'true' : 'false',
        ];
        /** @var HubSettings $hubSettings */
        $hubSettings = MainFactory::create('HubSettings', gm_get_conf('GAMBIO_HUB_CURL_TIMEOUT'));
        
        /** @var \HubCallbackApiClient $hubCallbackApiClient */
        $hubCallbackApiClient = MainFactory::create(
            'HubCallbackApiClient',
            MODULE_PAYMENT_GAMBIO_HUB_URL,
            new CurlRequest(),
            LogControl::get_instance(),
            $hubSettings
        );
        
        $params = ['source' => 'get_javascript_source', 'position' => (string)$position];
        
        /** @var \HubPublic\ValueObjects\HttpResponse $response */
        $response = $hubCallbackApiClient->execute('PayPal2Hub', true, $params, $query);
        
        if ($response->getStatusCode() !== 200) {
            throw new RuntimeException('Error retrieving JS URL from hub');
        }
        
        $responseBody                = json_decode($response->getBody(), true);
        $src                         = $responseBody['jssrc'];
        $src                         .= '&currency=' . $_SESSION['currency'];
        $_SESSION['paypalhub-jssrc'] = $src;
        
        return $src;
    }
}
